@@ -2,17 +2,16 @@
 
 from .base_context import ContextBuilder
 from .injection_context import InjectionContext
-from .provider import CachedProvider, ClassProvider, StatsProvider
+from .provider import CachedProvider, ClassProvider
 
 from ..cache.base import BaseCache
-from ..cache.basic import BasicCache
+from ..cache.in_memory import InMemoryCache
+from ..core.event_bus import EventBus
 from ..core.plugin_registry import PluginRegistry
+from ..core.profile import ProfileManager, ProfileManagerProvider
 from ..core.protocol_registry import ProtocolRegistry
-from ..ledger.base import BaseLedger
-from ..ledger.provider import LedgerProvider
-from ..issuer.base import BaseIssuer
-from ..holder.base import BaseHolder
-from ..verifier.base import BaseVerifier
+from ..core.goal_code_registry import GoalCodeRegistry
+from ..resolver.did_resolver import DIDResolver
 from ..tails.base import BaseTailsServer
 
 from ..protocols.actionmenu.v1_0.base_service import BaseMenuService
@@ -20,20 +19,16 @@ from ..protocols.actionmenu.v1_0.driver_service import DriverMenuService
 from ..protocols.didcomm_prefix import DIDCommPrefix
 from ..protocols.introduction.v0_1.base_service import BaseIntroductionService
 from ..protocols.introduction.v0_1.demo_service import DemoIntroductionService
-
-from ..storage.base import BaseStorage
-from ..storage.provider import StorageProvider
 from ..transport.wire_format import BaseWireFormat
 from ..utils.stats import Collector
-from ..wallet.base import BaseWallet
-from ..wallet.provider import WalletProvider
+from ..utils.dependencies import is_indy_sdk_module_installed
 
 
 class DefaultContextBuilder(ContextBuilder):
     """Default context builder."""
 
-    async def build(self) -> InjectionContext:
-        """Build the new injection context; set DIDComm prefix to emit."""
+    async def build_context(self) -> InjectionContext:
+        """Build the base injection context; set DIDComm prefix to emit."""
         context = InjectionContext(settings=self.settings)
         context.settings.set_default("default_label", "Aries Cloud Agent")
 
@@ -43,11 +38,20 @@ class DefaultContextBuilder(ContextBuilder):
             context.injector.bind_instance(Collector, collector)
 
         # Shared in-memory cache
-        context.injector.bind_instance(BaseCache, BasicCache())
+        context.injector.bind_instance(BaseCache, InMemoryCache())
 
         # Global protocol registry
         context.injector.bind_instance(ProtocolRegistry, ProtocolRegistry())
 
+        # Global goal code registry
+        context.injector.bind_instance(GoalCodeRegistry, GoalCodeRegistry())
+
+        # Global event bus
+        context.injector.bind_instance(EventBus, EventBus())
+
+        # Global did resolver
+        context.injector.bind_instance(DIDResolver, DIDResolver([]))
+
         await self.bind_providers(context)
         await self.load_plugins(context)
 
@@ -59,71 +63,20 @@ class DefaultContextBuilder(ContextBuilder):
     async def bind_providers(self, context: InjectionContext):
         """Bind various class providers."""
 
-        context.injector.bind_provider(
-            BaseStorage,
-            CachedProvider(
-                StatsProvider(
-                    StorageProvider(), ("add_record", "get_record", "search_records")
-                )
-            ),
-        )
-        context.injector.bind_provider(
-            BaseWallet,
-            CachedProvider(
-                StatsProvider(
-                    WalletProvider(),
-                    (
-                        "sign_message",
-                        "verify_message",
-                        # "pack_message",
-                        # "unpack_message",
-                        "get_local_did",
-                    ),
-                )
-            ),
-        )
+        # Bind global indy pool provider to be able to share pools between wallets
+        # It is important the ledger pool provider is available in the base context
+        # so it can be shared by all wallet instances. If we set it in the indy sdk
+        # profile provider it could mean other wallets won't have access to the provider
+        if is_indy_sdk_module_installed():
+            from ..ledger.indy import IndySdkLedgerPool, IndySdkLedgerPoolProvider
+
+            context.injector.bind_provider(
+                IndySdkLedgerPool,
+                CachedProvider(IndySdkLedgerPoolProvider(), ("ledger.pool_name",)),
+            )
+
+        context.injector.bind_provider(ProfileManager, ProfileManagerProvider())
 
-        context.injector.bind_provider(
-            BaseLedger,
-            CachedProvider(
-                StatsProvider(
-                    LedgerProvider(),
-                    (
-                        "create_and_send_credential_definition",
-                        "create_and_send_schema",
-                        "get_credential_definition",
-                        "get_schema",
-                    ),
-                )
-            ),
-        )
-        context.injector.bind_provider(
-            BaseIssuer,
-            StatsProvider(
-                ClassProvider(
-                    "aries_cloudagent.issuer.indy.IndyIssuer",
-                    ClassProvider.Inject(BaseWallet),
-                ),
-                ("create_credential_offer", "create_credential"),
-            ),
-        )
-        context.injector.bind_provider(
-            BaseHolder,
-            StatsProvider(
-                ClassProvider(
-                    "aries_cloudagent.holder.indy.IndyHolder",
-                    ClassProvider.Inject(BaseWallet),
-                ),
-                ("get_credential", "store_credential", "create_credential_request"),
-            ),
-        )
-        context.injector.bind_provider(
-            BaseVerifier,
-            ClassProvider(
-                "aries_cloudagent.verifier.indy.IndyVerifier",
-                ClassProvider.Inject(BaseLedger),
-            ),
-        )
         context.injector.bind_provider(
             BaseTailsServer,
             ClassProvider(
@@ -135,27 +88,27 @@ class DefaultContextBuilder(ContextBuilder):
         context.injector.bind_provider(
             BaseWireFormat,
             CachedProvider(
-                StatsProvider(
-                    ClassProvider(
-                        "aries_cloudagent.transport.pack_format.PackWireFormat"
-                    ),
-                    (
-                        # "encode_message", "parse_message"
-                    ),
-                )
+                # StatsProvider(
+                ClassProvider("aries_cloudagent.transport.pack_format.PackWireFormat"),
+                #    (
+                #        "encode_message", "parse_message"
+                #    ),
+                # )
             ),
         )
 
         # Allow action menu to be provided by driver
         context.injector.bind_instance(BaseMenuService, DriverMenuService(context))
         context.injector.bind_instance(
-            BaseIntroductionService, DemoIntroductionService(context)
+            BaseIntroductionService, DemoIntroductionService()
         )
 
     async def load_plugins(self, context: InjectionContext):
         """Set up plugin registry and load plugins."""
 
-        plugin_registry = PluginRegistry()
+        plugin_registry = PluginRegistry(
+            blocklist=self.settings.get("blocked_plugins", [])
+        )
         context.injector.bind_instance(PluginRegistry, plugin_registry)
 
         # Register standard protocol plugins
@@ -168,9 +121,14 @@ class DefaultContextBuilder(ContextBuilder):
             "aries_cloudagent.messaging.credential_definitions"
         )
         plugin_registry.register_plugin("aries_cloudagent.messaging.schemas")
+        plugin_registry.register_plugin("aries_cloudagent.messaging.jsonld")
         plugin_registry.register_plugin("aries_cloudagent.revocation")
+        plugin_registry.register_plugin("aries_cloudagent.resolver")
         plugin_registry.register_plugin("aries_cloudagent.wallet")
 
+        if context.settings.get("multitenant.admin_enabled"):
+            plugin_registry.register_plugin("aries_cloudagent.multitenant.admin")
+
         # Register external plugins
         for plugin_path in self.settings.get("external_plugins", []):
             plugin_registry.register_plugin(plugin_path)
