@@ -1,20 +1,21 @@
 from asynctest import TestCase as AsyncTestCase
 from asynctest import mock as async_mock
 
-from aries_cloudagent.config.injection_context import InjectionContext
-from aries_cloudagent.messaging.request_context import RequestContext
-from aries_cloudagent.messaging.responder import MockResponder
+from .....core.event_bus import EventBus, MockEventBus
+from .....core.in_memory import InMemoryProfile
+from .....messaging.request_context import RequestContext
+
 from .. import driver_service as test_module
 
 
 class TestActionMenuService(AsyncTestCase):
-    async def test_get_active_menu(self):
-        self.context = RequestContext(
-            base_context=InjectionContext(enforce_typing=False)
-        )
+    async def setUp(self):
+        self.session = InMemoryProfile.test_session()
+        self.context = RequestContext(self.session.profile)
 
-        self.responder = MockResponder()
-        self.context.injector.bind_instance(test_module.BaseResponder, self.responder)
+    async def test_get_active_menu(self):
+        mock_event_bus = MockEventBus()
+        self.context.profile.context.injector.bind_instance(EventBus, mock_event_bus)
 
         self.menu_service = await (
             test_module.DriverMenuService.service_handler()(self.context)
@@ -24,24 +25,21 @@ class TestActionMenuService(AsyncTestCase):
         connection.connection_id = "connid"
         thread_id = "thid"
 
-        await self.menu_service.get_active_menu(connection, thread_id)
+        await self.menu_service.get_active_menu(
+            self.context.profile, connection, thread_id
+        )
 
-        webhooks = self.responder.webhooks
-        assert len(webhooks) == 1
-        (result, target) = webhooks[0]
-        assert result == "get-active-menu"
-        assert target == {
+        assert len(mock_event_bus.events) == 1
+        (_, event) = mock_event_bus.events[0]
+        assert event.topic == "acapy::actionmenu::get-active-menu"
+        assert event.payload == {
             "connection_id": connection.connection_id,
             "thread_id": thread_id,
         }
 
     async def test_perform_menu_action(self):
-        self.context = RequestContext(
-            base_context=InjectionContext(enforce_typing=False)
-        )
-
-        self.responder = MockResponder()
-        self.context.injector.bind_instance(test_module.BaseResponder, self.responder)
+        mock_event_bus = MockEventBus()
+        self.context.profile.context.injector.bind_instance(EventBus, mock_event_bus)
 
         self.menu_service = await (
             test_module.DriverMenuService.service_handler()(self.context)
@@ -54,14 +52,17 @@ class TestActionMenuService(AsyncTestCase):
         thread_id = "thid"
 
         await self.menu_service.perform_menu_action(
-            action_name, action_params, connection, thread_id
+            self.context.profile,
+            action_name,
+            action_params,
+            connection,
+            thread_id,
         )
 
-        webhooks = self.responder.webhooks
-        assert len(webhooks) == 1
-        (result, target) = webhooks[0]
-        assert result == "perform-menu-action"
-        assert target == {
+        assert len(mock_event_bus.events) == 1
+        (_, event) = mock_event_bus.events[0]
+        assert event.topic == "acapy::actionmenu::perform-menu-action"
+        assert event.payload == {
             "connection_id": connection.connection_id,
             "thread_id": thread_id,
             "action_name": action_name,
