@@ -1,9 +1,8 @@
 """A presentation request content message."""
 
-
 from typing import Sequence
 
-from marshmallow import fields
+from marshmallow import EXCLUDE, fields
 
 from .....messaging.agent_message import AgentMessage, AgentMessageSchema
 from .....messaging.decorators.attach_decorator import (
@@ -13,7 +12,6 @@ from .....messaging.decorators.attach_decorator import (
 
 from ..message_types import PRESENTATION_REQUEST, PROTOCOL_PACKAGE
 
-
 HANDLER_CLASS = (
     f"{PROTOCOL_PACKAGE}.handlers."
     "presentation_request_handler.PresentationRequestHandler"
@@ -61,7 +59,7 @@ class PresentationRequest(AgentMessage):
                 (typically, list has length 1)
 
         """
-        return self.request_presentations_attach[index].indy_dict
+        return self.request_presentations_attach[index].content
 
 
 class PresentationRequestSchema(AgentMessageSchema):
@@ -71,8 +69,11 @@ class PresentationRequestSchema(AgentMessageSchema):
         """Presentation request schema metadata."""
 
         model_class = PresentationRequest
+        unknown = EXCLUDE
 
-    comment = fields.Str(description="Human-readable comment", required=False)
+    comment = fields.Str(
+        description="Human-readable comment", required=False, allow_none=True
+    )
     request_presentations_attach = fields.Nested(
         AttachDecoratorSchema,
         required=True,
